@@ -18,13 +18,32 @@ TransportSortProxyModel::~TransportSortProxyModel() = default;
 
 bool TransportSortProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
-    if (mTransportActivitiesAbstract) {
-        const auto activities = sourceModel()->index(source_row, 0).data(TransportModel::ActivitiesRole).toStringList();
-        return mTransportActivitiesAbstract->filterAcceptsRow(activities);
+    if (mTransportActivitiesAbstract && mEnablePlasmaActivities) {
+        const bool enableActivities = sourceModel()->index(source_row, TransportModel::EnabledActivitiesRole).data().toBool();
+        if (enableActivities) {
+            const auto activities = sourceModel()->index(source_row, TransportModel::ActivitiesRole).data().toStringList();
+            const bool result = mTransportActivitiesAbstract->filterAcceptsRow(activities);
+            // qDebug() << " result " << result << " identity name : " << sourceModel()->index(source_row,
+            // IdentityTreeModel::IdentityNameRole).data().toString();
+            return result;
+        }
     }
     return QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
 }
 
+bool TransportSortProxyModel::enablePlasmaActivities() const
+{
+    return mEnablePlasmaActivities;
+}
+
+void TransportSortProxyModel::setEnablePlasmaActivities(bool newEnablePlasmaActivities)
+{
+    if (mEnablePlasmaActivities != newEnablePlasmaActivities) {
+        mEnablePlasmaActivities = newEnablePlasmaActivities;
+        invalidateFilter();
+    }
+}
+
 TransportActivitiesAbstract *TransportSortProxyModel::transportActivitiesAbstract() const
 {
     return mTransportActivitiesAbstract;
