@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,7 +25,6 @@ public:
     Ui::TransportManagementWidgetNg ui;
     TransportManagementWidgetNg *const q;
 
-    // Slots
     void defaultClicked();
     void removeClicked();
     void renameClicked();
@@ -72,6 +71,25 @@ TransportManagementWidgetNg::TransportManagementWidgetNg(QWidget *parent)
     connect(d->ui.transportTreeView->selectionModel(), &QItemSelectionModel::selectionChanged, this, [this]() {
         d->updateButtonState();
     });
+    connect(d->ui.transportOnCurrentActivity, &QCheckBox::checkStateChanged, this, [this](Qt::CheckState state) {
+        d->ui.transportTreeView->setEnablePlasmaActivities(state == Qt::Checked);
+    });
+    d->ui.transportOnCurrentActivity->setVisible(false);
+}
+
+bool TransportManagementWidgetNg::enablePlasmaActivities() const
+{
+    return d->ui.transportTreeView->enablePlasmaActivities();
+}
+
+void TransportManagementWidgetNg::setEnablePlasmaActivities(bool newEnablePlasmaActivities)
+{
+    d->ui.transportOnCurrentActivity->setVisible(newEnablePlasmaActivities);
+}
+
+void TransportManagementWidgetNg::setTransportActivitiesAbstract(TransportActivitiesAbstract *activitiesAbstract)
+{
+    d->ui.transportTreeView->setTransportActivitiesAbstract(activitiesAbstract);
 }
 
 TransportManagementWidgetNg::~TransportManagementWidgetNg() = default;
@@ -137,7 +155,8 @@ void TransportManagementWidgetNgPrivate::removeClicked()
         ? i18n("Do you want to remove outgoing account '%1'?", ui.transportTreeView->selectionModel()->selectedRows().constFirst().data().toString())
         : i18np("Do you really want to remove this %1 outgoing account?", "Do you really want to remove these %1 outgoing accounts?", nbAccount);
 
-    const int rc = KMessageBox::questionTwoActions(q, msg, i18n("Remove outgoing account?"), KStandardGuiItem::remove(), KStandardGuiItem::cancel());
+    const int rc =
+        KMessageBox::questionTwoActions(q, msg, i18nc("@title:window", "Remove outgoing account?"), KStandardGuiItem::remove(), KStandardGuiItem::cancel());
     if (rc == KMessageBox::ButtonCode::SecondaryAction) {
         return;
     }
