@@ -7,6 +7,7 @@
 
 #include "kmailtransport_private_export.h"
 #include <QTreeView>
+#include <QTreeWidgetItem>
 
 namespace MailTransport
 {
@@ -24,6 +25,9 @@ public:
 
     [[nodiscard]] TransportSortProxyModel *transportSortProxyModel() const;
 
+    [[nodiscard]] bool enablePlasmaActivities() const;
+    void setEnablePlasmaActivities(bool newEnablePlasmaActivities);
+
 private:
     TransportSortProxyModel *const mTransportSortProxyModel;
 };
